pub enum Cond {
Rel(Expr, RelOp, Expr),
Class(Expr, Class),
Name(Ref),
NameOrRel {
subject: Expr,
op: RelOp,
name: Ref,
},
Not(Box<Cond>),
And(Box<Cond>, Box<Cond>),
Or(Box<Cond>, Box<Cond>),
}Variants
Rel(Expr, RelOp, Expr)
Class(Expr, Class)
Name(Ref)
NameOrRel
After AND or OR, a bare name that is either a condition-name or the object of an abbreviated relation; which one depends on what the name resolves to.
Not(Box<Cond>)
And(Box<Cond>, Box<Cond>)
Or(Box<Cond>, Box<Cond>)