pub enum Flag {
Condition(Ref),
Conditions(Ref, Ref),
Literals(Literal, Literal),
}Expand description
What a USING phrase of JSON PARSE sets for true, or for null, and for false, or not null: a condition-name set to true or to its WHEN SET TO FALSE value, one of two condition-names set to true, or one of two literals moved in.
Variants