pub struct Oo {
pub repository: Vec<ClassEntry>,
pub unit: OoUnit,
}Expand description
What a program, class or method knows of classes.
Fields
repository: Vec<ClassEntry>REPOSITORY CLASS entries: the outermost program’s for it and its contained programs, the class’s for the class and each of its methods.
unit: OoUnitImplementations