pub struct Slot {
pub field: usize,
pub occurrence: u16,
pub control: Option<usize>,
pub extended: usize,
pub data: usize,
pub size: usize,
}Expand description
The COBOL a program COPYs for the mapset: each map’s input and output structures.
Where one occurrence of a named field lies in a map’s symbolic structure: the offsets of its L
and F/A bytes and extended attributes (for the first member of a group, or a lone field), and
of its data. They are the offsets symbolic_map declares, which SEND MAP and RECEIVE MAP use.
Fields
field: usizeoccurrence: u16control: Option<usize>extended: usizedata: usizesize: usizeImplementations