pub fn parse(
tokens: &[Token],
options: Vec<String>,
) -> Result<Vec<Program>, Error>Expand description
Every program in the source, first to last, with nested programs after the one containing them, except that the first program comes ahead of the user-defined functions and prototypes before it, as the binder’s ENTRY statement makes it the one a run enters (assumption C270).