pub struct FreeSpan {
pub file: u16,
pub first: u32,
pub last: u32,
pub warning: Option<Error>,
}Expand description
Lines first to last of file file, read in free form, and the warning that says so; a
COPY member read in free form as the line that copies it was has none of its own.
Fields
file: u16first: u32last: u32warning: Option<Error>Implementations