pub struct Source {
pub text: String,
pub positions: Vec<Pos>,
pub options: Vec<String>,
pub debugging: Option<Vec<(u16, u32)>>,
}Fields
text: Stringpositions: Vec<Pos>For each char of text, where it came from.
options: Vec<String>debugging: Option<Vec<(u16, u32)>>None when debugging lines (D in column 7) were read as comments; else the file and line of each one read as program text.