pub struct HostVar {
pub var: Ref,
pub indicator: Option<Ref>,
pub colon: bool,
}Expand description
A host variable and the indicator variable that follows it.
Fields
var: Refindicator: Option<Ref>colon: boolWritten with its colon; an INTO list may name a host variable without one.