pub struct AssignItem {
pub reference: Ref,
pub explicit: bool,
}Expand description
ASSIGN TO a name, or ASSIGN TO DYNAMIC or USING a data-name: Micro Focus and GnuCOBOL take a name that is a data item’s, and the other two forms always, as the item holding the file’s name (Enterprise COBOL’s assignment-name is never a data item, Language Reference SC27-8713-03, ASSIGN clause).
Fields
reference: Refexplicit: boolDYNAMIC or USING was written.