pub fn parse_all_with(
text: &str,
libraries: &Libraries,
) -> Result<Vec<Program>, Error>Expand description
Every program in the source, in order, nested programs after the one that contains them. The libraries’ compliance level says how the source and its members are read.