pub fn read_copied(
input: &str,
file: u16,
debugging: bool,
compliance: Compliance,
copied_free: bool,
) -> Result<Source, Error>Expand description
Reads a COPY member’s text as read_under does, starting in free form when the line that
copies it is free form, as GnuCOBOL and Micro Focus carry the source format into a member.